==> estateplat-common-1.2.4-20190813.084306-215-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslLog.java <==
package cn.gtmap.estateplat.model.acceptance;


/*
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version 1.0, zhangyu
 * @description  一窗日志表
 */


import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

@Entity
@Table(name = "YCSL_LOG")
public class YcslLog implements Serializable {

    private static final long serialVersionUID = 5848321792060606824L;

    @Column(name = "ID")
    @Id
    private String id;
    @Column(name = "ACTION")
    private String action;
    @Column(name = "CONTENT")
    private String content;
    @Column(name = "CREATE_TIME")
    private String createTime;
    @Column(name = "IP")
    private String ip;
    @Column(name = "USER_ID")
    private String userId;


    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getAction() {
        return action;
    }

    public void setAction(String action) {
        this.action = action;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }
}

==> estateplat-common-1.2.4-20201113.091216-505-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslLog.java <==
package cn.gtmap.estateplat.model.acceptance;


/*
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version 1.0, zhangyu
 * @description  一窗日志表
 */


import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "YCSL_LOG")
public class YcslLog implements Serializable {

    private static final long serialVersionUID = 5848321792060606824L;

    @Column(name = "ID")
    @Id
    private String id;
    @Column(name = "ACTION")
    private String action;
    @Column(name = "CONTENT")
    private String content;
    @Column(name = "CREATE_TIME")
    private Date createTime;
    @Column(name = "IP")
    private String ip;
    @Column(name = "USER_ID")
    private String userId;


    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getAction() {
        return action;
    }

    public void setAction(String action) {
        this.action = action;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }
}
